@@ -1,8 +1,11 @@
 # Copyright (c) Microsoft Corporation
 # Licensed under the MIT License.
 
+from flask_cors import CORS
+from rai_core_flask.environments.base_environment import BaseEnvironment
 
-class LocalIPythonEnvironment:
+
+class LocalIPythonEnvironment(BaseEnvironment):
     """Environment class for local IPython environments.
 
     LocalIPythonEnvironment represents functionality to detect whether it is
@@ -10,24 +13,24 @@ class LocalIPythonEnvironment:
     Additionally, it can display corresponding visualizations.
     """
 
-    def __init__(self, ip, port):
+    def __init__(self, service):
         self.successfully_detected = False
         self.base_url = None
-        self.externally_available = None
-        self.port = port
 
         try:
             from IPython.display import HTML, display  # noqa: F401
         except NameError:
             self.successfully_detected = False
         else:
-            self.successfully_detected = True
-            self.base_url = "http://{0}:{1}".format(
-                ip,
-                port)
-            self.externally_available = True
+            if service.ip == "localhost" and not service.with_credentials:
+                self.successfully_detected = True
+                self.base_url = f"http://localhost:{service.port}"
 
     def display(self, html):
         """Display the passed HTML using IPython."""
         from IPython.display import HTML, display
         display(HTML(html))
+
+    def select(self, service):
+        service.with_credentials = False
+        service.cors = CORS(service.app)
